@@ -3,7 +3,7 @@
 # See the LICENSE file in the project root for more information
 
 package Search::Elasticsearch::Client::7_0::Direct;
-$Search::Elasticsearch::Client::7_0::Direct::VERSION = '7.712';
+$Search::Elasticsearch::Client::7_0::Direct::VERSION = '7.713';
 use Moo;
 with 'Search::Elasticsearch::Client::7_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -23,6 +23,7 @@ has 'data_frame_transform_deprecated' => ( is => 'lazy', init_arg => undef );
 has 'enrich'               => ( is => 'lazy', init_arg => undef );
 has 'eql'                  => ( is => 'lazy', init_arg => undef );
 has 'features'             => ( is => 'lazy', init_arg => undef );
+has 'fleet'                => ( is => 'lazy', init_arg => undef );
 has 'graph'                => ( is => 'lazy', init_arg => undef );
 has 'ilm'                  => ( is => 'lazy', init_arg => undef );
 has 'indices'              => ( is => 'lazy', init_arg => undef );
@@ -36,6 +37,7 @@ has 'nodes'                => ( is => 'lazy', init_arg => undef );
 has 'rollup'               => ( is => 'lazy', init_arg => undef );
 has 'searchable_snapshots' => ( is => 'lazy', init_arg => undef );
 has 'security'             => ( is => 'lazy', init_arg => undef );
+has 'shutdown'             => ( is => 'lazy', init_arg => undef );
 has 'snapshot'             => ( is => 'lazy', init_arg => undef );
 has 'slm'                  => ( is => 'lazy', init_arg => undef );
 has 'sql'                  => ( is => 'lazy', init_arg => undef );
@@ -95,6 +97,7 @@ sub _build_data_frame_transform_deprecated { shift->_build_namespace('DataFrameT
 sub _build_enrich               { shift->_build_namespace('Enrich') }
 sub _build_eql                  { shift->_build_namespace('Eql') }
 sub _build_features             { shift->_build_namespace('Features') }
+sub _build_fleet                { shift->_build_namespace('Fleet') }
 sub _build_graph                { shift->_build_namespace('Graph') }
 sub _build_ilm                  { shift->_build_namespace('ILM') }
 sub _build_indices              { shift->_build_namespace('Indices') }
@@ -108,6 +111,7 @@ sub _build_nodes                { shift->_build_namespace('Nodes') }
 sub _build_rollup               { shift->_build_namespace('Rollup') }
 sub _build_searchable_snapshots { shift->_build_namespace('SearchableSnapshots') }
 sub _build_security             { shift->_build_namespace('Security') }
+sub _build_shutdown             { shift->_build_namespace('Shutdown') }
 sub _build_snapshot             { shift->_build_namespace('Snapshot') }
 sub _build_slm                  { shift->_build_namespace('Slm') }
 sub _build_sql                  { shift->_build_namespace('SQL') }
@@ -133,7 +137,7 @@ Search::Elasticsearch::Client::7_0::Direct - Thin client with full support for E
 
 =head1 VERSION
 
-version 7.712
+version 7.713
 
 =head1 SYNOPSIS
 
